/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: query.h */
#ifndef __MORGOTHDBMA_QUERY_H__
#define __MORGOTHDBMA_QUERY_H__
#define MAX_ERROR_STRING 0XFF
#define MAX_QUERY_LENGTH 2048
#include <libpq-fe.h>
#include <string.h>
#include "consoleout.h"
PGconn* connect_db(char*);
PGconn* gtk_connect_db(char*,char*);
void clear_result(PGresult**);
void disconnect_db(PGconn**);
PGresult* execute_silent_query(PGconn*,char*);
PGresult* execute_query(PGconn*,char*);
void execute_printf_query(PGconn*,PGresult**,char*, char*,...);
void execute_printf(PGconn*,char****, int*, int*, char*, char*,...);
char*** p3c_execute_printf(PGconn*,int*, int*,char*,char*,...);
char*** pgres2pc3(const PGresult*,int*,int*);
void free_p3c(char****,int,int);
#endif
